=== modified file 'config/autorun.sh'
--- config/autorun.sh	2009-07-10 20:57:17 +0000
+++ config/autorun.sh	2009-08-10 22:36:25 +0000
@@ -41,6 +41,12 @@
   . config/pre_hook.sh
 fi
 
+# We need to some file here for the m4_sinclude, even if it's just empty
+if test ! -f config/plugin.ac
+then
+  touch config/plugin.ac
+fi
+
 # Try to detect the supported binaries if the user didn't
 # override that by pushing the environment variable
 if test x$LIBTOOLIZE = x; then

=== modified file 'config/register_plugins.py'
--- config/register_plugins.py	2009-07-27 17:26:22 +0000
+++ config/register_plugins.py	2009-08-09 01:21:44 +0000
@@ -26,16 +26,44 @@
 plugin_list=[]
 autogen_header="This file is generated, re-run %s to rebuild\n" % sys.argv[0]
 
+class ChangeProtectedFile(object):
+
+  def __init__(self, fname):
+    self.real_fname= fname
+    self.new_fname= "%s.new" % fname
+    self.new_file= open(self.new_fname,'w')
+
+  def write(self, text):
+    self.new_file.write(text)
+
+  # We've written all of this out into .new files, now we only copy them
+  # over the old ones if they are different, so that we don't cause 
+  # unnecessary recompiles
+  def close(self):
+    self.new_file.close()
+    if os.system('diff %s %s >/dev/null 2>&1' % (self.new_fname,self.real_fname)):
+      try:
+        os.unlink(self.real_fname)
+      except:
+        pass
+      os.rename(self.new_fname, self.real_fname)
+    try:
+      os.unlink(self.new_fname)
+    except:
+      pass
+
 if len(sys.argv)>1:
   top_srcdir=sys.argv[1]
   top_builddir=top_srcdir
 if len(sys.argv)>2:
   top_builddir=sys.argv[2]
 
-plugin_ac=open(os.path.join(top_builddir,'config','plugin.ac.new'),'w')
-plugin_am=open(os.path.join(top_srcdir,'config','plugin.am.new'),'w')
+plugin_ac=ChangeProtectedFile(os.path.join(top_builddir,'config','plugin.ac'))
+plugin_am=ChangeProtectedFile(os.path.join(top_srcdir,'config','plugin.am'))
+
 plugin_ac.write("dnl %s" % autogen_header)
 plugin_am.write("# %s" % autogen_header)
+plugin_am.write("PANDORA_DYNAMIC_LDADDS=\n")
 
 def accumulate_plugins(arg, dirname, fnames):
   if plugin_ini_fname in fnames:
@@ -68,7 +96,7 @@
       header= os.path.join(plugin['rel_path'], header)
       new_headers= "%s %s" % (new_headers, header)
   plugin['headers']= new_headers
-  
+
   if plugin.has_key('load_by_default'):
     plugin['load_by_default']=parser.getboolean('plugin','load_by_default')
   else:
@@ -97,7 +125,7 @@
     plugin['has_build_conditional']=False
     plugin['build_conditional']='"x${with_%(name)s_plugin}" = "xyes"' %plugin
 
-  # Turn this on later plugin_lib%(name)s_plugin_la_CPPFLAGS=$(AM_CPPFLAGS) -DDRIZZLE_DYNAMIC_PLUGIN %(cppflags)s
+  # Turn this on later plugin_lib%(name)s_plugin_la_CPPFLAGS=$(AM_CPPFLAGS) -DPANDORA_DYNAMIC_PLUGIN %(cppflags)s
 
   #
   # Write plugin build instructions into plugin.am file.
@@ -117,23 +145,24 @@
   plugin_lib%(name)s_plugin_la_CFLAGS=$(AM_CFLAGS) %(cflags)s
 
   plugin_lib%(name)s_plugin_la_SOURCES=%(sources)s
+  PANDORA_DYNAMIC_LDADDS+=${top_builddir}/plugin/lib%(name)s_plugin.la
 endif
 """ % plugin)
   # Add this once we're actually doing dlopen (and remove -avoid-version if
   # we move to ltdl
   #pkgplugin_LTLIBRARIES+=plugin/lib%(name)s_plugin.la
   #plugin_lib%(name)s_plugin_la_LDFLAGS=-module -avoid-version -rpath $(pkgplugindir) %(libs)s
-  #drizzled_drizzled_LDADD+=${top_builddir}/plugin/lib%(name)s_plugin.la
+
 
   if os.path.exists(plugin_am_file):
-    plugin_am.write('include %s\n' % plugin_am_file) 
+    plugin_am.write('include %s\n' % plugin_am_file)
 
   #
   # Write plugin config instructions into plugin.am file.
   #
   plugin_ac.write("\n\ndnl Config for %(title)s\n" % plugin)
   for m4_file in plugin_m4_files:
-    plugin_ac.write('m4_sinclude([%s])\n' % m4_file) 
+    plugin_ac.write('m4_sinclude([%s])\n' % m4_file)
 
   plugin_ac.write("""
 AC_ARG_WITH([%(name_with_dashes)s-plugin],[
@@ -168,32 +197,17 @@
   """ % plugin)
   if plugin['testsuite'] != "":
     plugin_ac.write("""
-        drizzled_plugin_test_list="%(testsuite)s,${drizzled_plugin_test_list}"
+        pandora_plugin_test_list="%(testsuite)s,${pandora_plugin_test_list}"
     """ % plugin)
 
   plugin_ac.write("""
-        drizzled_default_plugin_list="%(name)s,${drizzled_default_plugin_list}"
-        drizzled_builtin_list="builtin_%(name)s_plugin,${drizzled_builtin_list}"
-        drizzled_plugin_libs="${drizzled_plugin_libs} \${top_builddir}/plugin/lib%(name)s_plugin.la"
-	DRIZZLED_PLUGIN_DEP_LIBS="${DRIZZLED_PLUGIN_DEP_LIBS} %(plugin_dep_libs)s"
+        pandora_default_plugin_list="%(name)s,${pandora_default_plugin_list}"
+        pandora_builtin_list="builtin_%(name)s_plugin,${pandora_builtin_list}"
+        pandora_plugin_libs="${pandora_plugin_libs} \${top_builddir}/plugin/lib%(name)s_plugin.la"
+	PANDORA_PLUGIN_DEP_LIBS="${PANDORA_PLUGIN_DEP_LIBS} %(plugin_dep_libs)s"
       ])
 """ % plugin)
- 
+
 plugin_ac.close()
 plugin_am.close()
 
-# We've written all of this out into .new files, now we only copy them
-# over the old ones if they are different, so that we don't cause 
-# unnecessary recompiles
-for f in ('plugin.ac','plugin.am'):
-  fname= os.path.join(top_builddir,'config',f)
-  if os.system('diff %s.new %s >/dev/null 2>&1' % (fname,fname)):
-    try:
-      os.unlink(fname)
-    except:
-      pass
-    os.rename('%s.new' % fname, fname)
-  try:
-    os.unlink("%s.new" % fname)
-  except:
-    pass

=== modified file 'configure.ac'
--- configure.ac	2009-07-30 06:49:08 +0000
+++ configure.ac	2009-08-20 16:14:47 +0000
@@ -49,10 +49,9 @@
 AM_CONDITIONAL(HAVE_LCOV,[test "x$LCOV" != "x"])
 
 AC_CHECK_PROGS(YACC, ['bison -y'])
-if test -z "$YACC" && test "$building_from_bzr" = "yes"
-then
+AS_IF([test "x$YACC" = "x" -a "$building_from_bzr" = "yes"],[
   AC_MSG_ERROR(["bison is required for Drizzle to build from a bzr branch"])
-fi
+])
 
 
 AM_GNU_GETTEXT(external, need-formatstring-macros)
@@ -72,7 +71,7 @@
 PANDORA_REQUIRE_PTHREAD
 
 PANDORA_REQUIRE_LIBPROTOBUF
-PANDORA_PROTOBUF_RECENT
+PANDORA_PROTOBUF_REQUIRE_VERSION([2.0.3])
 PANDORA_REQUIRE_PROTOC
 
 #--------------------------------------------------------------------
@@ -655,55 +654,9 @@
 
 DRIZZLE_CHECK_MAX_INDEXES
 
-#--------------------------------------------------------------------
-# Declare our plugin modules
-# Has to be done late, as the plugin may need to check for existence of
-# functions tested above
-#--------------------------------------------------------------------
-
-m4_include(config/plugin.ac)
-dnl Add code here to read set plugin lists and  set drizzled_default_plugin_list
-AC_DEFINE_UNQUOTED([DRIZZLED_PLUGIN_LIST],[$drizzled_default_plugin_list],
-                   [List of plugins that should be loaded on startup if no
-                    value is given for --plugin-load])
-
-drizzled_builtin_list=`echo $drizzled_builtin_list | sed 's/, *$//'`
-AC_DEFINE_UNQUOTED([DRIZZLED_BUILTIN_LIST],[$drizzled_builtin_list],
-                   [List of plugins to be loaded in sql_builtin.cc])
-AC_SUBST(drizzled_plugin_test_list)
-AC_SUBST(drizzled_plugin_libs)
-
-AC_SUBST(mysql_plugin_dirs)
-AC_SUBST(mysql_plugin_libs)
-drizzled_plugin_defs=`echo $drizzled_plugin_defs | sed 's/, *$//'`
-AC_SUBST(drizzled_plugin_defs)
-AC_SUBST(DRIZZLED_PLUGIN_DEP_LIBS)
-
-dnl Must be done once we turn on warnings and such
-AC_CACHE_CHECK(
-  [whether __attribute__ visibility "hidden" is supported],
-  [ac_cv_can_use_hidden_],[
-    AC_LANG_PUSH(C++)
-    save_CXXFLAGS="${CXXFLAGS}"
-    CXXFLAGS="${AM_CXXFLAGS}"
-    AC_LINK_IFELSE([
-      AC_LANG_PROGRAM(
-        [[
-__attribute__((visibility ("hidden")))
-void testme() {  }
-        ]],[[testme()]]
-      )],  
-      [ac_cv_can_use_hidden_=yes],
-      [ac_cv_can_use_hidden_=no])
-    CXXFLAGS="${save_CXXFLAGS}"
-    AC_LANG_POP()])
-AS_IF([test "$ac_cv_can_use_hidden_" = "yes"],[
-  AC_DEFINE(HAVE_ATTR_HIDDEN, 1,
-  [Define to 1 if you have support for __attribute__((visibility("hidden")))])
-])
-
-
-AC_SUBST(pkgplugindir,"\$(pkglibdir)/plugin")
+dnl Has to be done late, as the plugin may need to check for existence of
+dnl functions tested above
+PANDORA_PLUGINS
 
 dnl GCC Precompiled Header Support
 dnl re-enable later

=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2009-08-17 20:20:04 +0000
+++ drizzled/Makefile.am	2009-08-20 17:27:08 +0000
@@ -381,11 +381,11 @@
 
 drizzled_LDADD = ${noinst_LTLIBRARIES} \
 		 $(top_builddir)/drizzled/message/libdrizzledmessage.la \
-		 $(drizzled_plugin_libs) \
+		 $(pandora_plugin_libs) \
 		 $(LDADD) $(LIBUUID) ${top_builddir}/gnulib/libgnu.la \
 		 $(LIBDL_LIBS) $(LIBPROTOBUF) $(LIBPCRE) $(LIBTBB) \
-		 $(DRIZZLED_PLUGIN_DEP_LIBS)
-drizzled_DEPENDENCIES= ${noinst_LTLIBRARIES} $(drizzled_plugin_libs)
+		 $(PANDORA_PLUGIN_DEP_LIBS)
+drizzled_DEPENDENCIES= ${noinst_LTLIBRARIES} $(pandora_plugin_libs)
 
 drizzled_LDFLAGS =
 

=== modified file 'drizzled/message/Makefile.am'
--- drizzled/message/Makefile.am	2009-07-29 17:45:51 +0000
+++ drizzled/message/Makefile.am	2009-08-20 17:27:08 +0000
@@ -39,6 +39,7 @@
 
 noinst_LTLIBRARIES = libdrizzledmessage.la
 
+libdrizzledmessage_la_CXXFLAGS = ${AM_CXXFLAGS} ${NO_WERROR}
 nodist_libdrizzledmessage_la_SOURCES = \
 		binary_log.pb.cc \
 		master_list.pb.cc \

=== modified file 'drizzled/plugin.h'
--- drizzled/plugin.h	2009-07-15 21:30:33 +0000
+++ drizzled/plugin.h	2009-08-09 01:21:44 +0000
@@ -38,7 +38,7 @@
 */
 
 
-#ifndef DRIZZLE_DYNAMIC_PLUGIN
+#ifndef PANDORA_DYNAMIC_PLUGIN
 #define __DRIZZLE_DECLARE_PLUGIN(NAME, DECLS) \
 drizzled::plugin::Manifest DECLS[]= {
 #else

=== modified file 'drizzled/sql_plugin.cc'
--- drizzled/sql_plugin.cc	2009-08-05 09:29:04 +0000
+++ drizzled/sql_plugin.cc	2009-08-20 17:27:08 +0000
@@ -46,16 +46,16 @@
 using namespace drizzled;
  
 typedef plugin::Manifest builtin_plugin[];
-extern builtin_plugin DRIZZLED_BUILTIN_LIST;
+extern builtin_plugin PANDORA_BUILTIN_LIST;
 static plugin::Manifest *drizzled_builtins[]=
 {
-  DRIZZLED_BUILTIN_LIST,(plugin::Manifest *)NULL
+  PANDORA_BUILTIN_LIST,(plugin::Manifest *)NULL
 };
 class sys_var_pluginvar;
 static vector<sys_var_pluginvar *> plugin_sysvar_vec;
 
 char *opt_plugin_load= NULL;
-const char *opt_plugin_load_default= QUOTE_ARG(DRIZZLED_PLUGIN_LIST);
+const char *opt_plugin_load_default= QUOTE_ARG(PANDORA_PLUGIN_LIST);
 char *opt_plugin_dir_ptr;
 char opt_plugin_dir[FN_REFLEN];
 static const char *plugin_declarations_sym= "_drizzled_plugin_declaration_";

=== modified file 'm4/pandora_canonical.m4'
--- m4/pandora_canonical.m4	2009-08-07 18:01:05 +0000
+++ m4/pandora_canonical.m4	2009-08-10 22:36:25 +0000
@@ -4,7 +4,7 @@
 dnl with or without modifications, as long as this notice is preserved.
 
 dnl Which version of the canonical setup we're using
-AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.41])
+AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.47])
 
 AC_DEFUN([PANDORA_FORCE_DEPEND_TRACKING],[
   dnl Force dependency tracking on for Sun Studio builds
@@ -138,6 +138,9 @@
     ])
   ])
 
+  PANDORA_USE_PIPE
+
+
   AM_CPPFLAGS="-I\${top_srcdir} -I\${top_builddir} ${AM_CPPFLAGS}"
   AM_CFLAGS="${AM_CFLAGS} ${CC_WARNINGS} ${CC_PROFILING} ${CC_COVERAGE}"
   AM_CXXFLAGS="${AM_CXXFLAGS} ${CXX_WARNINGS} ${CC_PROFILING} ${CC_COVERAGE}"

=== modified file 'm4/pandora_have_protobuf.m4'
--- m4/pandora_have_protobuf.m4	2009-07-26 20:11:34 +0000
+++ m4/pandora_have_protobuf.m4	2009-08-10 20:52:34 +0000
@@ -37,20 +37,26 @@
       AC_MSG_ERROR([libprotobuf is required for ${PACKAGE}. On Debian this can be found in libprotobuf-dev. On RedHat this can be found in protobuf-devel.]))
 ])
 
-AC_DEFUN([PANDORA_PROTOBUF_RECENT],[
+AC_DEFUN([PANDORA_PROTOBUF_REQUIRE_VERSION],[
   AC_REQUIRE([_PANDORA_SEARCH_LIBPROTOBUF])
+  p_recent_ver=$1
+  p_recent_ver_major=`echo $p_recent_ver | cut -f1 -d.`
+  p_recent_ver_minor=`echo $p_recent_ver | cut -f2 -d.`
+  p_recent_ver_patch=`echo $p_recent_ver | cut -f3 -d.`
+  p_recent_ver_hex=`printf "%d%03d%03d" $p_recent_ver_major $p_recent_ver_minor $p_recent_ver_patch` 
   AC_LANG_PUSH([C++])
-  AC_CACHE_CHECK([if protobuf is recent enough], [drizzle_cv_protobuf_recent],
+  AC_CACHE_CHECK([for protobuf >= $p_recent_ver],
+    [drizzle_cv_protobuf_recent],
     [AC_COMPILE_IFELSE([AC_LANG_PROGRAM([[
 #include <google/protobuf/descriptor.h>
-#if GOOGLE_PROTOBUF_VERSION < 2000002
+#if GOOGLE_PROTOBUF_VERSION < $p_recent_ver_hex
 # error Your version of Protobuf is too old
 #endif
       ]])],
-      [drizzle_cv_protobuf_recent=yes],
-      [drizzle_cv_protobuf_recent=no])])
+    [drizzle_cv_protobuf_recent=yes],
+    [drizzle_cv_protobuf_recent=no])])
   AS_IF([test "$drizzle_cv_protobuf_recent" = "no"],[
-    AC_MSG_ERROR([Your version of Google Protocol Buffers is too old. ${PACKAGE} requires at least version 2.0.2])
+    AC_MSG_ERROR([Your version of Google Protocol Buffers is too old. ${PACKAGE} requires at least version $p_recent_ver])
   ])
   AC_LANG_POP()
 ])

=== added file 'm4/pandora_plugins.m4'
--- m4/pandora_plugins.m4	1970-01-01 00:00:00 +0000
+++ m4/pandora_plugins.m4	2009-08-10 21:15:31 +0000
@@ -0,0 +1,34 @@
+dnl  Copyright (C) 2009 Sun Microsystems
+dnl This file is free software; Sun Microsystems
+dnl gives unlimited permission to copy and/or distribute it,
+dnl with or without modifications, as long as this notice is preserved.
+dnl--------------------------------------------------------------------
+dnl PANDORA_PLUGINS
+dnl Declare our plugin modules
+dnl--------------------------------------------------------------------
+
+AC_DEFUN([PANDORA_PLUGINS],[
+
+  m4_include(config/plugin.ac)
+  dnl Add code here to read set plugin lists and  set drizzled_default_plugin_list
+  AC_DEFINE_UNQUOTED([PANDORA_PLUGIN_LIST],[$pandora_default_plugin_list],
+                     [List of plugins that should be loaded on startup if no
+                      value is given for --plugin-load])
+
+  pandora_builtin_list=`echo $pandora_builtin_list | sed 's/, *$//'`
+  AC_DEFINE_UNQUOTED([PANDORA_BUILTIN_LIST],[$pandora_builtin_list],
+                     [List of plugins to be built in])
+
+  AC_SUBST(pandora_plugin_test_list)
+  AC_SUBST(pandora_plugin_libs)
+
+  pandora_plugin_defs=`echo $pandora_plugin_defs | sed 's/, *$//'`
+  AC_SUBST(pandora_plugin_defs)
+
+  AC_SUBST(PANDORA_PLUGIN_DEP_LIBS)
+  AC_SUBST(pkgplugindir,"\$(pkglibdir)/plugin")
+])
+
+AC_DEFUN([PANDORA_ADD_PLUGIN_DEP_LIB],[
+  PANDORA_PLUGIN_DEP_LIBS="${PANDORA_PLUGIN_DEP_LIBS} $*"
+])

=== added file 'm4/pandora_use_pipe.m4'
--- m4/pandora_use_pipe.m4	1970-01-01 00:00:00 +0000
+++ m4/pandora_use_pipe.m4	2009-08-10 06:09:21 +0000
@@ -0,0 +1,36 @@
+dnl -*- mode: m4; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+dnl vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+dnl   
+dnl pandora-build: A pedantic build system
+dnl Copyright (C) 2009 Sun Microsystems, Inc.
+dnl This file is free software; the Free Software Foundation
+dnl gives unlimited permission to copy and/or distribute it,
+dnl with or without modifications, as long as this notice is preserved.
+dnl
+dnl From Monty Taylor
+dnl
+dnl Test if we can Use -pipe to avoid making temp files during the compile.
+dnl Should speed up compile on slower disks
+
+AC_DEFUN([PANDORA_USE_PIPE],[
+
+  AS_IF([test "$GCC" = "yes"],[
+    AC_CACHE_CHECK([for working -pipe], [pandora_cv_use_pipe], [
+      AC_RUN_IFELSE([AC_LANG_SOURCE([[
+#include <stdio.h>
+
+int main(int argc, char** argv)
+{
+  (void) argc; (void) argv;
+  return 0;
+}
+      ]])],
+      [pandora_cv_use_pipe=yes],
+      [pandora_cv_use_pipe=no])
+    ])
+    AS_IF([test "$pandora_cv_use_pipe" = "yes"],[
+      AM_CFLAGS="-pipe ${AM_CFLAGS}"
+      AM_CXXFLAGS="-pipe ${AM_CXXFLAGS}"
+    ])
+  ])
+])

=== modified file 'm4/pandora_warnings.m4'
--- m4/pandora_warnings.m4	2009-08-07 18:01:05 +0000
+++ m4/pandora_warnings.m4	2009-08-10 20:34:41 +0000
@@ -208,6 +208,7 @@
       NO_REDUNDANT_DECLS="-Wno-redundant-decls"
       dnl TODO: Figure out a better way to deal with this:
       PROTOSKIP_WARNINGS="-Wno-effc++ -Wno-shadow -Wno-missing-braces"
+      NO_WERROR="-Wno-error"
       INNOBASE_SKIP_WARNINGS="-Wno-shadow -Wno-cast-align"
       
     ])
@@ -251,6 +252,7 @@
     CXX_WARNINGS="+w +w2 -xwe -xport64 -errtags=yes ${CXX_WARNINGS_FULL} ${W_FAIL}"
     PROTOSKIP_WARNINGS="-erroff=attrskipunsup,doubunder,reftotemp,wbadinitl,identexpected,inllargeuse,truncwarn1,signextwarn,partinit,notused,badargtype2w,wbadinit"
     NO_UNREACHED="-erroff=E_STATEMENT_NOT_REACHED"
+    NO_WERROR="-errwarn=%none"
 
   ])
 
@@ -261,5 +263,6 @@
   AC_SUBST(NO_STRICT_ALIASING)
   AC_SUBST(PROTOSKIP_WARNINGS)
   AC_SUBST(INNOBASE_SKIP_WARNINGS)
+  AC_SUBST(NO_WERROR)
 
 ])

=== modified file 'plugin/archive/plugin.am'
--- plugin/archive/plugin.am	2009-07-26 18:58:41 +0000
+++ plugin/archive/plugin.am	2009-08-10 07:08:51 +0000
@@ -19,11 +19,13 @@
 		$(top_builddir)/mystrings/libmystrings.la \
 		$(LDADD)
 
+if BUILD_ARCHIVE_PLUGIN
 noinst_PROGRAMS+= \
 		plugin/archive/archive_test \
 		plugin/archive/archive_reader \
 		plugin/archive/archive_performance \
 		plugin/archive/concurrency_test
+endif
 
 plugin_archive_archive_performance_SOURCES= plugin/archive/archive_performance.cc
 plugin_archive_archive_performance_LDADD= $(test_archive_LDADD)

=== modified file 'plugin/gearman_udf/plugin.ac'
--- plugin/gearman_udf/plugin.ac	2009-07-14 22:35:09 +0000
+++ plugin/gearman_udf/plugin.ac	2009-08-09 01:21:44 +0000
@@ -2,4 +2,4 @@
 AS_IF([test "x$ac_cv_libgearman" = "xno"],
       AC_MSG_WARN([libgearman not found: not building gearman_udf plugin.]))
 
-DRIZZLED_PLUGIN_DEP_LIBS="${DRIZZLED_PLUGIN_DEP_LIBS} ${LTLIBGEARMAN}"
+PANDORA_ADD_PLUGIN_DEP_LIB([${LTLIBGEARMAN}])

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2009-08-18 07:00:39 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2009-08-20 17:27:08 +0000
@@ -125,7 +125,7 @@
 
 
 StorageEngine* innodb_engine_ptr= NULL;
-#ifdef DRIZZLE_DYNAMIC_PLUGIN
+#ifdef PANDORA_DYNAMIC_PLUGIN
 /* These must be weak global variables in the dynamic plugin. */
 #ifdef __WIN__
 struct drizzled::plugin::Manifest*	builtin_innobase_plugin_ptr;
@@ -140,7 +140,7 @@
 innodb_plugin_init(void);
 /*====================*/
 		/* out: TRUE if the dynamic InnoDB plugin should start */
-#endif /* DRIZZLE_DYNAMIC_PLUGIN */
+#endif /* PANDORA_DYNAMIC_PLUGIN */
 
 static const long AUTOINC_OLD_STYLE_LOCKING = 0;
 static const long AUTOINC_NEW_STYLE_LOCKING = 1;
@@ -1629,12 +1629,12 @@
 
 	innodb_engine_ptr= new InnobaseEngine(innobase_engine_name);
 
-#ifdef DRIZZLE_DYNAMIC_PLUGIN
+#ifdef PANDORA_DYNAMIC_PLUGIN
 	if (!innodb_plugin_init()) {
 		errmsg_printf(ERRMSG_LVL_ERROR, "InnoDB plugin init failed.");
 		return -1;
 	}
-#endif /* DRIZZLE_DYNAMIC_PLUGIN */
+#endif /* PANDORA_DYNAMIC_PLUGIN */
 
 	ut_a(DATA_MYSQL_TRUE_VARCHAR == (ulint)DRIZZLE_TYPE_VARCHAR);
 
@@ -8983,7 +8983,7 @@
   NULL
 };
 
-#ifdef DRIZZLE_DYNAMIC_PLUGIN
+#ifdef PANDORA_DYNAMIC_PLUGIN
 struct st_mysql_sys_var
 {
 	DRIZZLE_PLUGIN_VAR_HEADER;
@@ -9132,7 +9132,7 @@
 
 	return(true);
 }
-#endif /* DRIZZLE_DYNAMIC_PLUGIN */
+#endif /* PANDORA_DYNAMIC_PLUGIN */
 
 drizzle_declare_plugin(innobase)
 {

=== modified file 'plugin/innobase/plugin.ac'
--- plugin/innobase/plugin.ac	2009-07-26 21:24:10 +0000
+++ plugin/innobase/plugin.ac	2009-08-09 01:21:44 +0000
@@ -41,7 +41,7 @@
 	 *solaris*|*SunOS*)
            AM_CFLAGS="$AM_CFLAGS -DUNIV_SOLARIS";;
   esac
-  INNODB_DYNAMIC_CFLAGS="-DDRIZZLE_DYNAMIC_PLUGIN"
+  INNODB_DYNAMIC_CFLAGS="-DPANDORA_DYNAMIC_PLUGIN"
   case "$target_cpu" in
 	x86_64)
 		# The AMD64 ABI forbids absolute addresses in shared libraries
@@ -76,6 +76,30 @@
       AC_MSG_RESULT(no)
     ]
     )
+
+dnl Must be done once we turn on warnings and such
+AC_CACHE_CHECK(
+  [whether __attribute__ visibility "hidden" is supported],
+  [ac_cv_can_use_hidden_],[
+    AC_LANG_PUSH(C++)
+    save_CXXFLAGS="${CXXFLAGS}"
+    CXXFLAGS="${AM_CXXFLAGS} ${CXXFLAGS}"
+    AC_LINK_IFELSE([
+      AC_LANG_PROGRAM(
+        [[
+__attribute__((visibility ("hidden")))
+void testme() {  }
+        ]],[[testme()]]
+      )],  
+      [ac_cv_can_use_hidden_=yes],
+      [ac_cv_can_use_hidden_=no])
+    CXXFLAGS="${save_CXXFLAGS}"
+    AC_LANG_POP()])
+AS_IF([test "$ac_cv_can_use_hidden_" = "yes"],[
+  AC_DEFINE(HAVE_ATTR_HIDDEN, 1,
+  [Define to 1 if you have support for __attribute__((visibility("hidden")))])
+])
+
   ])
 
 AC_INNODB_ACTIONS

=== modified file 'plugin/logging_gearman/plugin.ac'
--- plugin/logging_gearman/plugin.ac	2009-07-14 22:35:09 +0000
+++ plugin/logging_gearman/plugin.ac	2009-08-09 01:21:44 +0000
@@ -1,5 +1,5 @@
 PANDORA_HAVE_LIBGEARMAN
 AS_IF([test "x$ac_cv_libgearman" = "xno"],
       AC_MSG_WARN([libgearman not found: not building logging_gearman plugin.]))
+PANDORA_ADD_PLUGIN_DEP_LIB([${LTLIBGEARMAN}])
 
-DRIZZLED_PLUGIN_DEP_LIBS="${DRIZZLED_PLUGIN_DEP_LIBS} ${LTLIBGEARMAN}"

=== removed file 'plugin/md5/Makefile.am'
--- plugin/md5/Makefile.am	2009-03-02 15:57:39 +0000
+++ plugin/md5/Makefile.am	1970-01-01 00:00:00 +0000
@@ -1,29 +0,0 @@
-# Copyright (C) 2006 MySQL AB
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-AM_CPPFLAGS += $(SSL_CFLAGS)
-
-if BUILD_MD5_UDF
-EXTRA_LTLIBRARIES=	libmd5udf.la
-pkgplugin_LTLIBRARIES=	@plugin_md5_shared_target@
-libmd5udf_la_LDFLAGS=	-module -avoid-version -rpath $(pkgplugindir)
-libmd5udf_la_LIBADD=	$(CRYPTO_LIBS)
-libmd5udf_la_CPPFLAGS=	${AM_CPPFLAGS} -DDRIZZLE_DYNAMIC_PLUGIN
-libmd5udf_la_SOURCES=	md5udf.cc
-
-EXTRA_LIBRARIES=	libmd5udf.a
-pkgplugin_LIBRARIES=	@plugin_md5_static_target@
-libmd5udf_a_SOURCES=	md5udf.cc
-endif

=== modified file 'tests/Makefile.am'
--- tests/Makefile.am	2009-08-13 18:15:51 +0000
+++ tests/Makefile.am	2009-08-20 17:27:08 +0000
@@ -21,7 +21,7 @@
 EXTRA_SCRIPTS = 	valgrind.supp $(PRESCRIPTS)
 GENSCRIPTS =		install_test_db dtr test-run
 PRESCRIPTS =		test-run.pl stress-test.pl
-PLUGIN_TESTS =		$(drizzled_plugin_test_list)
+PLUGIN_TESTS =		$(pandora_plugin_test_list)
 ALL_TESTS =		main,big,$(PLUGIN_TESTS)
 noinst_SCRIPTS =	$(GENSCRIPTS) $(PRESCRIPTS)
 CLEANFILES = 		$(GENSCRIPTS) mtr

